@@ -1,24 +1,23 @@
 /*
-    GNU Gama C++ library
-    Copyright (C) 1999, 2010  Ales Cepek <cepek@fsv.cvut.cz>
-                  2011  Vaclav Petras <wenzeslaus@gmail.com>
-                  2013  Ales Cepek <cepek@gnu.org>
+  GNU Gama C++ library
+  Copyright (C) 1999, 2010  Ales Cepek <cepek@fsv.cvut.cz>
+                2011  Vaclav Petras <wenzeslaus@gmail.com>
+                2013, 2018  Ales Cepek <cepek@gnu.org>
 
-    This file is part of the GNU Gama C++ library
+  This file is part of the GNU Gama C++ library
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 3 of the License, or
-    (at your option) any later version.
+  This library is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  You should have received a copy of the GNU General Public License
+  along with GNU Gama.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /** \file residuals_observations.h
@@ -37,12 +36,13 @@
 #include <gnu_gama/utf8.h>
 #include <algorithm>
 
-static float ResidualsObservations_N01(float x)   // local helper function
-{
-   double D, f;
-   GNU_gama::NormalDistribution(double(x), D, f);
-   return D;
-}
+/* replaced by a lambda function below, see KS test */
+//static double ResidualsObservations_N01(double x)   // local helper function
+//{
+//   double D, f;
+//   GNU_gama::NormalDistribution(double(x), D, f);
+//   return D;
+//}
 
 
 /* *******************************************************************
@@ -60,8 +60,8 @@ public:
   bool operator()(int a, int b)
     {
       using namespace std;
-      GNU_gama::local::Double sa = fabs(IS->studentized_residual(a));
-      GNU_gama::local::Double sb = fabs(IS->studentized_residual(b));
+      double sa = fabs(IS->studentized_residual(a));
+      double sb = fabs(IS->studentized_residual(b));
       return sa > sb;
     }
 };
@@ -78,19 +78,19 @@ public:
     WriteShortObservationName(OutStream& outStream) : out(outStream)
     {}
 
-    void visit(Distance* obs) { out << T_GaMa_distance; }
-    void visit(Direction* obs) { out << T_GaMa_direction; }
-    void visit(Angle* obs) { out << T_GaMa_angle; }
-    void visit(H_Diff* obs) { out << T_GaMa_levell; }
-    void visit(S_Distance* obs) { out << T_GaMa_s_distance; }
-    void visit(Z_Angle* obs) { out << T_GaMa_z_angle; }
-    void visit(X* obs) { out << T_GaMa_x; }
-    void visit(Y* obs) { out << T_GaMa_y; }
-    void visit(Z* obs) { out << T_GaMa_z; }
-    void visit(Xdiff* obs) { out << T_GaMa_xdiff; }
-    void visit(Ydiff* obs) { out << T_GaMa_ydiff; }
-    void visit(Zdiff* obs) { out << T_GaMa_zdiff; }
-    void visit(Azimuth* obs) { out << T_GaMa_azimuth; }
+    void visit(Distance* /*obs*/) { out << T_GaMa_distance; }
+    void visit(Direction* /*obs*/) { out << T_GaMa_direction; }
+    void visit(Angle* /*obs*/) { out << T_GaMa_angle; }
+    void visit(H_Diff* /*obs*/) { out << T_GaMa_levell; }
+    void visit(S_Distance* /*obs*/) { out << T_GaMa_s_distance; }
+    void visit(Z_Angle* /*obs*/) { out << T_GaMa_z_angle; }
+    void visit(X* /*obs*/) { out << T_GaMa_x; }
+    void visit(Y* /*obs*/) { out << T_GaMa_y; }
+    void visit(Z* /*obs*/) { out << T_GaMa_z; }
+    void visit(Xdiff* /*obs*/) { out << T_GaMa_xdiff; }
+    void visit(Ydiff* /*obs*/) { out << T_GaMa_ydiff; }
+    void visit(Zdiff* /*obs*/) { out << T_GaMa_zdiff; }
+    void visit(Azimuth* /*obs*/) { out << T_GaMa_azimuth; }
 
 };
 
@@ -101,7 +101,6 @@ void ResidualsObservations(GNU_gama::local::LocalNetwork* IS, OutStream& out)
 
   using namespace std;
   using namespace GNU_gama::local;
-  using GNU_gama::local::Double;
 
   const Vec&    v      = IS->residuals();
   const int     pocmer = IS->sum_observations();
@@ -109,16 +108,16 @@ void ResidualsObservations(GNU_gama::local::LocalNetwork* IS, OutStream& out)
 
   vector<int> odlehla;
 
-  Double kki = IS->conf_int_coef();
+  double kki = IS->conf_int_coef();
   int imax = 1;         // index of maximal studentized residual
   {
     using namespace std;
-    Double maxno = 0;
+    double maxno = 0;
     for (int i=1; i<=pocmer; i++)
       {
         if (IS->obs_control(i) < 0.1) continue;
 
-        Double no = fabs(IS->studentized_residual(i));
+        double no = fabs(IS->studentized_residual(i));
         if (no > maxno) {
           maxno = no;
           imax = i;
@@ -195,7 +194,7 @@ void ResidualsObservations(GNU_gama::local::LocalNetwork* IS, OutStream& out)
 
           pm->accept(&nameVisitor);
 
-          Double f  = IS->obs_control(i);
+          double f  = IS->obs_control(i);
           out.precision(1);
           out.width(5);
           out << f;
@@ -221,7 +220,7 @@ void ResidualsObservations(GNU_gama::local::LocalNetwork* IS, OutStream& out)
           if (f >= 0.1)
             {
               using namespace std;
-              Double no = fabs(IS->studentized_residual(i));
+              double no = fabs(IS->studentized_residual(i));
               out << no;
 
               if (i == imax)
@@ -236,11 +235,11 @@ void ResidualsObservations(GNU_gama::local::LocalNetwork* IS, OutStream& out)
               if ( (pm->ptr_cluster())->covariance_matrix.bandWidth() == 0 &&
                   (f >=5 || (f >= 0.1 && no > kki)))
                 {
-                  Double em = v(i) / (IS->wcoef_res(i)*IS->weight_obs(i));
+                  double em = v(i) / (IS->wcoef_res(i)*IS->weight_obs(i));
                   out.width(7);
                   out << em*sc;
 
-                  Double ev = em - v(i);
+                  double ev = em - v(i);
                   out.width(7);
                   out << ev*sc;
                 }
@@ -253,6 +252,7 @@ void ResidualsObservations(GNU_gama::local::LocalNetwork* IS, OutStream& out)
         }
     }
 
+#ifdef GNU_GAMA_KOLMOGOROV_SMIRNOV
   if (pocmer >= 30)
     {
       using namespace GNU_gama::local;
@@ -263,8 +263,8 @@ void ResidualsObservations(GNU_gama::local::LocalNetwork* IS, OutStream& out)
 
       { // ****** Kolmogorov-Smirnov
 
-        Vec   pv(pocmer);
-        Float pvvar = 0, pvstr = 0, p;
+        Vec    pv(pocmer);
+        double pvvar = 0, pvstr = 0, p;
         {
           for (int i=1; i<=pocmer; i++)
             {
@@ -284,7 +284,13 @@ void ResidualsObservations(GNU_gama::local::LocalNetwork* IS, OutStream& out)
         if (pvvar)
           for (int i=1; i<=pocmer; i++) pv(i) = (pv(i) - pvstr) / pvvar;
 
-        float  ks, prob;
+        auto ResidualsObservations_N01 =
+          [](double x) -> double {
+             double D, f;
+             GNU_gama::NormalDistribution(double(x), D, f);
+             return D;
+          };
+        double  ks, prob;
         GNU_gama::KStest(pv.begin(),
                          pocmer, ResidualsObservations_N01, ks, prob);
 
@@ -296,8 +302,9 @@ void ResidualsObservations(GNU_gama::local::LocalNetwork* IS, OutStream& out)
 
       }
     }
+#endif
 
-  if (Double cond = IS->cond())
+  if (double cond = IS->cond())
     {
       out.setf(ios_base::scientific, ios_base::floatfield);
       out.precision(1);
